Russian XFig 3.2.2 (rus X xfig patch)
Ключевые слова: rus, X, xfig, patch, (найти похожие документы)
Subj : Russian XFig 3.2.2
diff -u -N -r xfig.3.2.2/main.c xfig.3.2.2_/main.c
--- xfig.3.2.2/main.c Tue Jun 30 02:25:55 1998
+++ xfig.3.2.2_/main.c Mon Oct 19 15:25:12 1998
@@ -182,6 +182,8 @@
XtOffset(appresPtr, image_editor), XtRString, (caddr_t) NULL},
{"magnification", "Magnification", XtRFloat, sizeof(float),
XtOffset(appresPtr, magnification), XtRFloat, (caddr_t) & F100},
+ {"encoding", "Encoding", XtRString, sizeof(char *),
+ XtOffset(appresPtr, encoding), XtRString, (caddr_t) "ISO8859"},
{"paper_size", "Papersize", XtRString, sizeof(char *),
XtOffset(appresPtr, paper_size), XtRString, (caddr_t) NULL},
{"multiple", XtCOrientation, XtRBoolean, sizeof(Boolean),
@@ -282,6 +284,7 @@
{"-multiple", ".multiple", XrmoptionNoArg, "True"},
{"-normalFont", ".normalFont", XrmoptionSepArg, 0},
{"-noscalablefonts", ".scalablefonts", XrmoptionNoArg, "False"},
+ {"-encoding", ".encoding", XrmoptionSepArg, "ISO8859"},
{"-notrack", ".trackCursor", XrmoptionNoArg, "False"},
{"-paper_size", ".paper_size", XrmoptionSepArg, (caddr_t) NULL},
{"-pheight", ".pheight", XrmoptionSepArg, 0},
@@ -395,6 +398,7 @@
[-userscale <scale>] \
[-userunit <units>] \
[-visual <visual>] \
+[-encoding <fontencoding>] \
[file] \
\n \
\n \
diff -u -N -r xfig.3.2.2/resources.h xfig.3.2.2_/resources.h
--- xfig.3.2.2/resources.h Sat Jun 6 04:40:14 1998
+++ xfig.3.2.2_/resources.h Mon Oct 19 15:33:47 1998
@@ -168,6 +168,8 @@
int transparent; /* transparent color for GIF export
(-2=none, -1=background) */
float magnification; /* export/print magnification */
+ char *encoding; /* X font encoding (defaults to
+ iso8859) [BT] */
Boolean showballoons; /* show popup messages when user passes over buttons */
char *spellcheckcommand; /* spell check command e.g.
"spell %s" or "ispell -l < %s | sort -u" */
diff -u -N -r xfig.3.2.2/w_drawprim.c xfig.3.2.2_/w_drawprim.c
--- xfig.3.2.2/w_drawprim.c Sat Jun 6 03:42:27 1998
+++ xfig.3.2.2_/w_drawprim.c Mon Oct 19 15:39:41 1998
@@ -116,7 +116,9 @@
x_fontinfo[f].template = ps_fontinfo[f+1].name;
} else {
strcpy(template,x_fontinfo[0].template); /* nope, check for font size 0 */
- strcat(template,"0-0-*-*-*-*-*-*");
+ strcat(template,"0-0-*-*-*-*-");
+ strcat(template, appres.encoding );
+ strcat(template, "-*");
if ((fontlist = XListFonts(tool_d, template, 1, &count))==0)
appres.SCALABLEFONTS = False; /* none, turn off request for them */
}
@@ -130,10 +132,12 @@
nf = NULL;
strcpy(template,x_fontinfo[f].template);
strcat(template,"*-*-*-*-*-*-");
/* add ISO8859 (if not Symbol font or ZapfDingbats) to font name */
if (strstr(template,"symbol") == NULL &&
- strstr(template,"dingbats") == NULL)
- strcat(template,"ISO8859-*");
+ strstr(template,"dingbats") == NULL) {
+ strcat(template, appres.encoding );
+ strcat(template,"-*");
+ }
else
strcat(template,"*-*");
/* don't free the Fontlist because we keep pointers into it */
@@ -276,10 +280,12 @@
strcpy(template,x_fontinfo[fnum].template);
/* attach pointsize to font name */
strcat(template,"%d-*-*-*-*-*-");
/* add ISO8859 (if not Symbol font or ZapfDingbats) to font name */
if (strstr(template,"symbol") == NULL &&
- strstr(template,"dingbats") == NULL)
- strcat(template,"ISO8859-*");
+ strstr(template,"dingbats") == NULL) {
+ strcat(template,appres.encoding);
+ strcat(template,"-*");
+ }
else
strcat(template,"*-*");
/* use the pixel field instead of points in the fontname so that the
@@ -130,10 +132,12 @@
strcpy(template,x_fontinfo[f].template);
strcat(template,"*-*-*-*-*-*-");
- /* add ISO8859 (if not Symbol font or ZapfDingbats) to font name */
+ /* add encoding (if not Symbol font or ZapfDingbats) to font name */
if (strstr(template,"symbol") == NULL &&
@@ -276,10 +280,12 @@
/* attach pointsize to font name */
strcat(template,"%d-*-*-*-*-*-");
- /* add ISO8859 (if not Symbol font or ZapfDingbats) to font name */
+ /* add encoding (if not Symbol font or ZapfDingbats) to font name */
if (strstr(template,"symbol") == NULL &&